netapp_ontap.models.advanced_rights API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.advanced_rights`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class AdvancedRightsSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the AdvancedRights object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `append_data: bool GET POST PATCH`

    Append DAta

  `delete: bool GET POST PATCH`

    Delete

  `delete_child: bool GET POST PATCH`

    Delete Child

  `execute_file: bool GET POST PATCH`

    Execute File

  `full_control: bool GET POST PATCH`

    Full Control

  `read_attr: bool GET POST PATCH`

    Read Attributes

  `read_data: bool GET POST PATCH`

    Read Data

  `read_ea: bool GET POST PATCH`

    Read Extended Attributes

  `read_perm: bool GET POST PATCH`

    Read Permissions

  `synchronize: bool GET`

    Synchronize

  `write_attr: bool GET POST PATCH`

    Write Attributes

  `write_data: bool GET POST PATCH`

    Write Data

  `write_ea: bool GET POST PATCH`

    Write Extended Attributes

  `write_owner: bool GET POST PATCH`

    Write Owner

  `write_perm: bool GET POST PATCH`

    Write Permission